@@ -28,6 +28,7 @@ from neutron_lib.api.definitions import data_plane_status
 from neutron_lib.api.definitions import default_subnetpools
 from neutron_lib.api.definitions import dhcpagentscheduler
 from neutron_lib.api.definitions import dns
+from neutron_lib.api.definitions import dns_domain_keywords
 from neutron_lib.api.definitions import dns_domain_ports
 from neutron_lib.api.definitions import dvr
 from neutron_lib.api.definitions import empty_string_filtering
@@ -84,7 +85,9 @@ from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
+from neutron_lib.api.definitions import rbac_address_scope
 from neutron_lib.api.definitions import rbac_security_groups
+from neutron_lib.api.definitions import rbac_subnetpool
 from neutron_lib.api.definitions import revisionifmatch
 from neutron_lib.api.definitions import router_admin_state_down_before_update
 from neutron_lib.api.definitions import router_availability_zone
@@ -136,6 +139,7 @@ _ALL_API_DEFINITIONS = {
     default_subnetpools,
     dhcpagentscheduler,
     dns,
+    dns_domain_keywords,
     dns_domain_ports,
     dvr,
     empty_string_filtering,
@@ -192,7 +196,9 @@ _ALL_API_DEFINITIONS = {
     qos_port_network_policy,
     qos_rule_type_details,
     qos_rules_alias,
+    rbac_address_scope,
     rbac_security_groups,
+    rbac_subnetpool,
     revisionifmatch,
     router_admin_state_down_before_update,
     router_availability_zone,
