@@ -59,9 +59,14 @@ DEVICE_OWNER_AGENT_GW = (DEVICE_OWNER_NETWORK_PREFIX +
                          "floatingip_agent_gateway")
 DEVICE_OWNER_ROUTER_SNAT = (DEVICE_OWNER_NETWORK_PREFIX +
                             "router_centralized_snat")
+# TODO(johnsom) Remove after these stop being used. Neutron-LBaaS is now
+#               retired (train) and these should no longer be necessary.
 DEVICE_OWNER_LOADBALANCER = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCER"
 DEVICE_OWNER_LOADBALANCERV2 = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCERV2"
 
+# Device owner for distributed services (e.g OVN Metadata/DHCP).
+DEVICE_OWNER_DISTRIBUTED = DEVICE_OWNER_NETWORK_PREFIX + "distributed"
+
 DEVICE_OWNER_PREFIXES = (DEVICE_OWNER_NETWORK_PREFIX,
                          DEVICE_OWNER_NEUTRON_PREFIX)
 
@@ -97,21 +102,34 @@ IP_ANY = {IP_VERSION_4: IPv4_ANY, IP_VERSION_6: IPv6_ANY}
 
 IPv6_LLA_PREFIX = 'fe80::/64'
 
-DHCP_RESPONSE_PORT = 68
+DHCP_CLIENT_PORT = 68
+DHCP_RESPONSE_PORT = 67
 DHCPV6_CLIENT_PORT = 546
+DHCPV6_RESPONSE_PORT = 547
 
 FLOODING_ENTRY = ('00:00:00:00:00:00', '0.0.0.0')
 
+# Agent process name and description
+AGENT_PROCESS_DHCP = 'neutron-dhcp-agent'
+AGENT_PROCESS_L3 = 'neutron-l3-agent'
+AGENT_PROCESS_LINUXBRIDGE = 'neutron-linuxbridge-agent'
+AGENT_PROCESS_MACVTAP = 'neutron-macvtap-agent'
+AGENT_PROCESS_METADATA = 'neutron-metadata-agent'
+AGENT_PROCESS_METERING = 'neutron-metering-agent'
+AGENT_PROCESS_NIC_SWITCH = 'neutron-sriov-nic-agent'
+AGENT_PROCESS_OVN_METADATA = 'neutron-ovn-metadata-agent'
+AGENT_PROCESS_OVS = 'neutron-openvswitch-agent'
+
 AGENT_TYPE_DHCP = 'DHCP agent'
-AGENT_TYPE_OVS = 'Open vSwitch agent'
-AGENT_TYPE_LINUXBRIDGE = 'Linux bridge agent'
-AGENT_TYPE_OFA = 'OFA driver agent'
 AGENT_TYPE_L3 = 'L3 agent'
-AGENT_TYPE_LOADBALANCER = 'Loadbalancer agent'
-AGENT_TYPE_METERING = 'Metering agent'
-AGENT_TYPE_METADATA = 'Metadata agent'
-AGENT_TYPE_NIC_SWITCH = 'NIC Switch agent'
+AGENT_TYPE_LINUXBRIDGE = 'Linux bridge agent'
 AGENT_TYPE_MACVTAP = 'Macvtap agent'
+AGENT_TYPE_METADATA = 'Metadata agent'
+AGENT_TYPE_METERING = 'Metering agent'
+AGENT_TYPE_NIC_SWITCH = 'NIC Switch agent'
+AGENT_TYPE_OFA = 'OFA driver agent'
+AGENT_TYPE_OVS = 'Open vSwitch agent'
+
 L2_AGENT_TOPIC = 'N/A'
 
 L3_AGENT_MODE_DVR = 'dvr'
@@ -124,7 +142,6 @@ DVR_SNAT_BOUND = 'dvr_snat_bound'
 PORT_BINDING_EXT_ALIAS = 'binding'
 L3_AGENT_SCHEDULER_EXT_ALIAS = 'l3_agent_scheduler'
 DHCP_AGENT_SCHEDULER_EXT_ALIAS = 'dhcp_agent_scheduler'
-LBAAS_AGENT_SCHEDULER_EXT_ALIAS = 'lbaas_agent_scheduler'
 L3_DISTRIBUTED_EXT_ALIAS = 'dvr'
 L3_HA_MODE_EXT_ALIAS = 'l3-ha'
 SUBNET_ALLOCATION_EXT_ALIAS = 'subnet_allocation'
@@ -326,8 +343,11 @@ VXLAN_ENCAP_OVERHEAD = 30
 
 # For DNS extension
 DNS_DOMAIN_DEFAULT = 'openstacklocal.'
+DNS_LABEL_KEYWORDS = ['project_id', 'project_name', 'user_name', 'user_id']
 DNS_LABEL_MAX_LEN = 63
-DNS_LABEL_REGEX = "^[a-z0-9-]{1,%d}$" % DNS_LABEL_MAX_LEN
+DNS_LABEL_REGEX = "^([a-z0-9-]{1,%d}|%s)$" % (
+                   DNS_LABEL_MAX_LEN,
+                   '<' + '>|<'.join(DNS_LABEL_KEYWORDS) + '>')
 
 # max value for TCP, UDP, SCTP ports
 PORT_MAX = 2**16 - 1
@@ -429,7 +449,10 @@ ETHERTYPE_IPV6 = 0x86DD
 IP_PROTOCOL_NAME_ALIASES = {PROTO_NAME_IPV6_ICMP_LEGACY:
                             PROTO_NAME_IPV6_ICMP}
 
-IP_PROTOCOL_NUM_TO_NAME_MAP = {str(v): k for k, v in IP_PROTOCOL_MAP.items()}
+# We only want one mapping from '58' to 'ipv6-icmp' since that is the
+# normalized string, the name to number mapping can have both
+IP_PROTOCOL_NUM_TO_NAME_MAP = ({str(v): k for k, v in IP_PROTOCOL_MAP.items()
+                               if k != PROTO_NAME_IPV6_ICMP_LEGACY})
 
 # When using iptables-save we specify '-p {proto}',
 # but sometimes those values are not identical.  This is a map
@@ -560,7 +583,8 @@ IP_ALLOWED_VERSIONS = [IP_VERSION_4, IP_VERSION_6]
 PORT_RANGE_MIN = 1
 PORT_RANGE_MAX = 65535
 
-DHCPV6_CLIENT_PORT = 546
+ETHERTYPE_MIN = 0
+ETHERTYPE_MAX = 65535
 
 # Configuration values for accept_ra sysctl, copied from linux kernel
 # networking (netdev) tree, file Documentation/networking/ip-sysctl.txt
